mod dto;
mod entity;
mod handler;
mod params;
mod repository;
mod response;
mod routes;
mod service;
mod state;

use crate::state::app::AppState;

use sea_orm::Database;
use std::env;
use std::sync::Arc;
use tokio::net::TcpListener;

#[tokio::main]
async fn main() {
    dotenvy::dotenv().ok();
    let db_url = env::var("DATABASE_URL").expect(".env 文件中没有设置 DATABASE_URL");
    let upload_path = env::var("UPLOAD_PATH").expect(".env 文件中没有设置 UPLOAD_PATH");
    let port = env::var("PORT").expect(".env 文件中没有设置 PORT");

    let db_conn = Database::connect(&db_url).await.expect("连接数据库失败");

    let app_state = AppState {
        db_conn,
        upload_path,
    };

    let app = routes::create_routes(Arc::new(app_state));
    let listener = TcpListener::bind(format!("0.0.0.0:{}", port))
        .await
        .unwrap();
    axum::serve(listener, app).await.unwrap();
}
